@@ -1,4 +1,4 @@
-package Zonemaster::Test::DNSSEC v0.1.0;
+package Zonemaster::Test::DNSSEC v1.0.0;
 
 ###
 ### This test module implements DNSSEC tests.
@@ -89,14 +89,12 @@ Readonly::Hash our %algo_properties => (
         description => q{ECDSA Curve P-384 with SHA-384},
         mnemonic    => q{ECDSAP384SHA384},
     },
-    (map { $_ => {
-               status      => $ALGO_STATUS_UNASSIGNED,
-               description => q{Unassigned},
-           } } (15..122) ),
-    (map { $_ => {
-               status      => $ALGO_STATUS_RESERVED,
-               description => q{Reserved},
-           } } (123..251) ),
+    (
+        map { $_ => { status => $ALGO_STATUS_UNASSIGNED, description => q{Unassigned}, } } ( 15 .. 122 )
+    ),
+    (
+        map { $_ => { status => $ALGO_STATUS_RESERVED, description => q{Reserved}, } } ( 123 .. 251 )
+    ),
     252 => {
         status      => $ALGO_STATUS_RESERVED,
         description => q{Reserved for Indirect Keys},
@@ -118,7 +116,6 @@ Readonly::Hash our %algo_properties => (
     },
 );
 
-
 ###
 ### Entry points
 ###
@@ -139,17 +136,16 @@ sub all {
         }
         else {
             push @results,
-              info(
-                ADDITIONAL_DNSKEY_SKIPPED => { }
-              );
+              info( ADDITIONAL_DNSKEY_SKIPPED => {} );
         }
         push @results, $class->dnssec08( $zone );
         push @results, $class->dnssec09( $zone );
         push @results, $class->dnssec10( $zone );
+        push @results, $class->dnssec11( $zone );
     }
 
     return @results;
-}
+} ## end sub all
 
 ###
 ### Metadata Exposure
@@ -255,17 +251,28 @@ sub metadata {
               NSEC3_NOT_SIGNED
               HAS_NSEC3 )
         ],
+        dnssec11 => [
+            qw(
+              DELEGATION_NOT_SIGNED
+              DELEGATION_SIGNED
+              ),
+        ],
     };
 } ## end sub metadata
 
 sub translation {
     return {
         "ADDITIONAL_DNSKEY_SKIPPED" => "No DNSKEYs found. Additional tests skipped.",
-        "ALGORITHM_DEPRECATED"    => "The DNSKEY with tag {keytag} uses deprecated algorithm number {algorithm}/({description}).",
-        "ALGORITHM_OK"            => "The DNSKEY with tag {keytag} uses algorithm number {algorithm}/({description}), which is OK.",
-        "ALGORITHM_RESERVED"      => "The DNSKEY with tag {keytag} uses reserved algorithm number {algorithm}/({description}).",
-        "ALGORITHM_UNASSIGNED"    => "The DNSKEY with tag {keytag} uses unassigned algorithm number {algorithm}/({description}).",
-        "ALGORITHM_PRIVATE"       => "The DNSKEY with tag {keytag} uses private algorithm number {algorithm}/({description}).",
+        "ALGORITHM_DEPRECATED" =>
+          "The DNSKEY with tag {keytag} uses deprecated algorithm number {algorithm}/({description}).",
+        "ALGORITHM_OK" =>
+          "The DNSKEY with tag {keytag} uses algorithm number {algorithm}/({description}), which is OK.",
+        "ALGORITHM_RESERVED" =>
+          "The DNSKEY with tag {keytag} uses reserved algorithm number {algorithm}/({description}).",
+        "ALGORITHM_UNASSIGNED" =>
+          "The DNSKEY with tag {keytag} uses unassigned algorithm number {algorithm}/({description}).",
+        "ALGORITHM_PRIVATE" =>
+          "The DNSKEY with tag {keytag} uses private algorithm number {algorithm}/({description}).",
         "ALGORITHM_UNKNOWN"       => "The DNSKEY with tag {keytag} uses unknown algorithm number {algorithm}.",
         "COMMON_KEYTAGS"          => "There are both DS and DNSKEY records with key tags {keytags}.",
         "DNSKEY_AND_DS"           => "{parent} sent a DS record, and {child} a DNSKEY record.",
@@ -282,11 +289,16 @@ sub translation {
         "DS_MATCHES_DNSKEY"        => "DS record with keytag {keytag} matches the DNSKEY with the same tag.",
         "DS_MATCH_FOUND"           => "At least one DS record with a matching DNSKEY record was found.",
         "DS_MATCH_NOT_FOUND"       => "No DS record with a matching DNSKEY record was found.",
-        "DURATION_LONG" => "RRSIG with keytag {tag} and covering type(s) {types} has a duration of {duration} seconds, which is too long.",
-        "DURATION_OK" => "RRSIG with keytag {tag} and covering type(s) {types} has a duration of {duration} seconds, which is just fine.",
-        "RRSIG_EXPIRED" => "RRSIG with keytag {tag} and covering type(s) {types} has already expired (expiration is: {expiration}).",
-        "REMAINING_SHORT" => "RRSIG with keytag {tag} and covering type(s) {types} has a remaining validity of {duration} seconds, which is too short.",
-        "REMAINING_LONG" => "RRSIG with keytag {tag} and covering type(s) {types} has a remaining validity of {duration} seconds, which is too long.",
+        "DURATION_LONG" =>
+"RRSIG with keytag {tag} and covering type(s) {types} has a duration of {duration} seconds, which is too long.",
+        "DURATION_OK" =>
+"RRSIG with keytag {tag} and covering type(s) {types} has a duration of {duration} seconds, which is just fine.",
+        "RRSIG_EXPIRED" =>
+          "RRSIG with keytag {tag} and covering type(s) {types} has already expired (expiration is: {expiration}).",
+        "REMAINING_SHORT" =>
+"RRSIG with keytag {tag} and covering type(s) {types} has a remaining validity of {duration} seconds, which is too short.",
+        "REMAINING_LONG" =>
+"RRSIG with keytag {tag} and covering type(s) {types} has a remaining validity of {duration} seconds, which is too long.",
         "EXTRA_PROCESSING_BROKEN" => "Server at {server} sent {keys} DNSKEY records, and {sigs} RRSIG records.",
         "EXTRA_PROCESSING_OK"     => "Server at {server} sent {keys} DNSKEY records and {sigs} RRSIG records.",
         "HAS_NSEC"                => "The zone has NSEC records.",
@@ -319,6 +331,8 @@ sub translation {
         "SOA_SIGNED"             => "At least one RRSIG correctly signs the SOA RRset.",
         "TOO_MANY_ITERATIONS" =>
           "The number of NSEC3 iterations is {count}, which is too high for key length {keylength}.",
+        "DELEGATION_NOT_SIGNED" => "Delegation from parent to child is not properly signed {reason}.",
+        "DELEGATION_SIGNED"     => "Delegation from parent to child is properly signed.",
     };
 } ## end sub translation
 
@@ -378,6 +392,8 @@ sub policy {
         "SOA_SIGNATURE_OK"             => "DEBUG",
         "SOA_SIGNED"                   => "DEBUG",
         "TOO_MANY_ITERATIONS"          => "WARNING",
+        "DELEGATION_NOT_SIGNED"        => "ERROR",
+        "DELEGATION_SIGNED"            => "INFO",
     };
 } ## end sub policy
 
@@ -424,13 +440,13 @@ sub dnssec01 {
                 push @results,
                   info(
                     DS_DIGTYPE_NOT_OK => {
-                        keytag => $ds->keytag,
+                        keytag  => $ds->keytag,
                         digtype => $ds->digtype
                     }
                   );
             }
-        }
-    }
+        } ## end foreach my $ds ( @ds )
+    } ## end else [ if ( @ds == 0 ) ]
 
     return @results;
 } ## end sub dnssec01
@@ -467,9 +483,7 @@ sub dnssec02 {
 
         if ( scalar( keys %dnskey ) == 0 ) {
             push @results,
-              info(
-                NO_DNSKEY => { }
-              );
+              info( NO_DNSKEY => {} );
             return @results;
         }
 
@@ -504,17 +518,13 @@ sub dnssec02 {
             }
             if ( $found ) {
                 push @results,
-                  info(
-                    DS_MATCH_FOUND => { }
-                  );
+                  info( DS_MATCH_FOUND => {} );
             }
             else {
                 push @results,
-                  info(
-                    DS_MATCH_NOT_FOUND => { }
-                  );
+                  info( DS_MATCH_NOT_FOUND => {} );
             }
-        }
+        } ## end if ( @common )
         else {
             push @results,
               info(
@@ -548,7 +558,7 @@ sub dnssec03 {
         push @results,
           info(
             NO_NSEC3PARAM => {
-                server => ($param_p ? $param_p->answerfrom : '<no response>'),
+                server => ( $param_p ? $param_p->answerfrom : '<no response>' ),
             }
           );
     }
@@ -574,7 +584,7 @@ sub dnssec03 {
                         }
                       );
                 }
-            }
+            } ## end if ( $iter > 100 )
             else {
                 push @results,
                   info(
@@ -583,8 +593,8 @@ sub dnssec03 {
                     }
                   );
             }
-        }
-    }
+        } ## end foreach my $n3p ( @nsec3params)
+    } ## end else [ if ( @nsec3params == 0)]
 
     return @results;
 } ## end sub dnssec03
@@ -608,8 +618,8 @@ sub dnssec04 {
     my @soa_sigs = $soa_p->get_records( 'RRSIG', 'answer' );
 
     foreach my $sig ( @key_sigs, @soa_sigs ) {
-        my $duration = $sig->expiration - $sig->inception;
-        my $remaining = $sig->expiration - int($key_p->timestamp);
+        my $duration  = $sig->expiration - $sig->inception;
+        my $remaining = $sig->expiration - int( $key_p->timestamp );
         if ( $remaining < 0 ) {    # already expired
             push @results,
               info(
@@ -660,7 +670,7 @@ sub dnssec04 {
                 }
               );
         }
-    }
+    } ## end foreach my $sig ( @key_sigs...)
 
     return @results;
 } ## end sub dnssec04
@@ -771,7 +781,7 @@ sub dnssec06 {
                 }
               );
         }
-    }
+    } ## end foreach my $key_p ( @{$key_aref...})
 
     return @results;
 } ## end sub dnssec06
@@ -806,7 +816,7 @@ sub dnssec07 {
         push @results,
           info(
             DNSKEY_AND_DS => {
-                child => $key_p->answerfrom,
+                child  => $key_p->answerfrom,
                 parent => $ds_p->answerfrom,
             }
           );
@@ -878,7 +888,7 @@ sub dnssec08 {
                 }
               );
         }
-    }
+    } ## end foreach my $sig ( @sigs )
 
     if ( $ok ) {
         push @results,
@@ -890,9 +900,7 @@ sub dnssec08 {
     }
     else {
         push @results,
-          info(
-            DNSKEY_NOT_SIGNED => {}
-          );
+          info( DNSKEY_NOT_SIGNED => {} );
     }
 
     return @results;
@@ -946,10 +954,10 @@ sub dnssec09 {
                 SOA_SIGNATURE_NOT_OK => {
                     signature => $sig->keytag,
                     error     => $msg,
-                 }
-               );
+                }
+              );
         }
-    }
+    } ## end foreach my $sig ( @sigs )
 
     if ( $ok ) {
         push @results,
@@ -961,9 +969,7 @@ sub dnssec09 {
     }
     else {
         push @results,
-          info(
-            SOA_NOT_SIGNED => { }
-          );
+          info( SOA_NOT_SIGNED => {} );
     }
 
     return @results;
@@ -1011,7 +1017,7 @@ sub dnssec10 {
                     my $msg = q{};
                     if (
                         $sig->verify_time(
-                            [ grep { name($_->name) eq name($sig->name) } @nsec ],
+                            [ grep { name( $_->name ) eq name( $sig->name ) } @nsec ],
                             \@dnskeys, $test_p->timestamp, $msg
                         )
                       )
@@ -1030,15 +1036,11 @@ sub dnssec10 {
 
                     if ( $ok ) {
                         push @results,
-                          info(
-                            NSEC_SIGNED => {}
-                          );
+                          info( NSEC_SIGNED => {} );
                     }
                     else {
                         push @results,
-                          info(
-                            NSEC_NOT_SIGNED => {}
-                        );
+                          info( NSEC_NOT_SIGNED => {} );
                     }
                 } ## end foreach my $sig ( @sigs )
             } ## end if ( $nsec->covers( $name...))
@@ -1076,7 +1078,7 @@ sub dnssec10 {
                     my $msg = q{};
                     if (
                         $sig->verify_time(
-                            [ grep { name($_->name) eq name($sig->name) } @nsec3 ],
+                            [ grep { name( $_->name ) eq name( $sig->name ) } @nsec3 ],
                             \@dnskeys, $test_p->timestamp, $msg
                         )
                       )
@@ -1094,15 +1096,11 @@ sub dnssec10 {
                     }
                     if ( $ok ) {
                         push @results,
-                          info(
-                            NSEC3_SIGNED => {}
-                          );
+                          info( NSEC3_SIGNED => {} );
                     }
                     else {
                         push @results,
-                          info(
-                            NSE3C_NOT_SIGNED => {}
-                          );
+                          info( NSE3C_NOT_SIGNED => {} );
                     }
                 } ## end foreach my $sig ( @sigs )
             } ## end if ( $nsec3->covers( $name...))
@@ -1128,6 +1126,67 @@ sub dnssec10 {
     return @results;
 } ## end sub dnssec10
 
+### The error reporting in dnssec11 is deliberately simple, since the point of
+### the test case is to give a pass/fail test for the delegation step from the
+### parent as a whole.
+sub dnssec11 {
+    my ( $class, $zone ) = @_;
+    my @results;
+
+    my $ds_p = $zone->parent->query_auth( $zone->name->string, 'DS' );
+    if ( not $ds_p ) {
+        return info( DELEGATION_NOT_SIGNED => { keytag => 'none', reason => 'no_ds_packet' } );
+    }
+
+    my $dnskey_p = $zone->query_auth( $zone->name->string, 'DNSKEY', { dnssec => 1 } );
+    if ( not $dnskey_p ) {
+        return info( DELEGATION_NOT_SIGNED => { keytag => 'none', reason => 'no_dnskey_packet' } );
+    }
+
+    my %ds = map { $_->keytag => $_ } $ds_p->get_records_for_name( 'DS', $zone->name->string );
+    my %dnskey = map { $_->keytag => $_ } $dnskey_p->get_records_for_name( 'DNSKEY', $zone->name->string );
+    my %rrsig  = map { $_->keytag => $_ } $dnskey_p->get_records_for_name( 'RRSIG',  $zone->name->string );
+
+    if ( scalar( keys %ds ) > 0 ) {
+        foreach my $tag ( keys %ds ) {
+            my $ds  = $ds{$tag};
+            my $key = $dnskey{$tag};
+            my $sig = $rrsig{$tag};
+
+            if ( $key ) {
+                if ( $ds->verify( $key ) ) {
+                    if ( $sig ) {
+                        my $msg = '';
+                        my $ok =
+                          $sig->verify_time( [ values %dnskey ], [ values %dnskey ], $dnskey_p->timestamp, $msg );
+                        if ( $ok ) {
+                            return info( DELEGATION_SIGNED => { keytag => $tag } );
+                        }
+                        else {
+                            push @results,
+                              info( DELEGATION_NOT_SIGNED => { keytag => $tag, reason => "signature: $msg" } );
+                        }
+                    }
+                    else {
+                        push @results, info( DELEGATION_NOT_SIGNED => { keytag => $tag, reason => 'no_signature' } );
+                    }
+                }
+                else {
+                    push @results, info( DELEGATION_NOT_SIGNED => { keytag => $tag, reason => 'dnskey_no_match' } );
+                }
+            } ## end if ( $key )
+            else {
+                push @results, info( DELEGATION_NOT_SIGNED => { keytag => $tag, reason => 'no_dnskey' } );
+            }
+        } ## end foreach my $tag ( keys %ds )
+    } ## end if ( scalar( keys %ds ...))
+    else {
+        push @results, info( DELEGATION_NOT_SIGNED => { keytag => 'none', reason => 'no_ds' } );
+    }
+
+    return @results;
+} ## end sub dnssec11
+
 1;
 
 =head1 NAME
@@ -1212,6 +1271,10 @@ Check that the SOA RRset is signed.
 
 Check for the presence of either NSEC or NSEC3, with proper coverage and signatures.
 
+=item dnssec11($zone)
+
+Check that the delegation step from parent is properly signed.
+
 =back
 
 =cut
